All platforms.

systems.bread.alpha.cache


cache!clj/smultimethod


pluginclj/s

(plugin)
(plugin config)

Returns a plugin that renders a static file with the fully rendered HTML body of each response.

Returns a plugin that renders a static file with the fully rendered
HTML body of each response.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries