(define-route {path :path dispatcher :dispatcher/type :as route-data})Takes a map containing at least the following keys:
Takes a map containing *at least* the following keys: - :path - :dispatcher/type Returns a single route spec as a vector. Preserves all other keys in the returned route spec data.
(query component)Get the query for this component.
Get the query for this component.
(query-key component)Get the key at which this component should show up in ::bread/data.
Get the key at which this component should show up in ::bread/data.
(routes cpt)Takes a component (with metadata) and returns a vector of route definitions, themselves vectors.
Takes a component (with metadata) and returns a vector of route definitions, themselves vectors.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |