systems.bread.alpha.dispatcher


pluginclj/s

(plugin)

pullclj/s

(pull dispatcher)

Get the (pull ...) form for the given dispatcher.

Get the (pull ...) form for the given dispatcher.
raw docstring

pull-specclj/s

(pull-spec {:dispatcher/keys [pull]})

Gets the pull spec from the given dispatcher. Adds :db/id to the list of fields to return if it is not already included.

Gets the pull spec from the given dispatcher. Adds :db/id to the list
of fields to return if it is not already included.
raw docstring

query-keyclj/s

(query-key dispatcher)

Get from the component layer the key at which to db the dispatched query within the ::bread/expansions map

Get from the component layer the key at which to db the dispatched query
within the ::bread/expansions map
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries