systems.bread.alpha.post


by-slug*-expansionclj/s

(by-slug*-expansion {{post-type :post/type
                      post-status :post/status
                      :or {post-status :post.status/published}
                      :as dispatcher}
                       :systems.bread.alpha.core/dispatcher
                     :as req})

Returns an expansion for querying a single post by :slugs. Observes the options in ::bread/dispatcher, which may specify:

  • :post/type (default nil, meaning all types)
  • :post/status (default :post.status/published)
Returns an expansion for querying a single post by :slugs. Observes
the options in ::bread/dispatcher, which may specify:
- :post/type (default nil, meaning all types)
- :post/status (default :post.status/published)
raw docstring

expand-postclj/s

(expand-post result)

cljdoc builds & hosts documentation for Clojure/Script libraries