systems.bread.alpha.schema


commentsclj/s

Schema for Post Comments.

Schema for Post Comments.
raw docstring

fieldsclj/s

Schema for arbitrary fields

Schema for arbitrary fields
raw docstring

i18nclj/s

Schema for translatable content.

Schema for translatable content.
raw docstring

initialclj/s

Standard schema for the Bread CMS database.

Standard schema for the Bread CMS database.
raw docstring

Schema for navigation Menus.

Schema for navigation Menus.
raw docstring

migrationsclj/s

Schema for database migrations, so that schema migrations can be reified and self-documenting.

Schema for database migrations, so that schema migrations
can be reified and self-documenting.
raw docstring

postsclj/s

Minimal schema for posts, the central content type of Bread CMS.

Minimal schema for posts, the central content type of Bread CMS.
raw docstring

revisionsclj/s

Schema for Post Revisions.

Schema for Post Revisions.
raw docstring

rolesclj/s

Schema for roles and authorization.

Schema for roles and authorization.
raw docstring

taxonsclj/s

Schema for taxons, ways of subdividing posts arbitrarily.

Schema for taxons, ways of subdividing posts arbitrarily.
raw docstring

thingsclj/s

Schema for generic db entities AKA "Things" that can have children, slugs, sort order, authorship, and a UUID.

Schema for generic db entities AKA "Things" that can have children,
slugs, sort order, authorship, and a UUID.
raw docstring

usersclj/s

Schema for users.

Schema for users.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries