systems.bread.alpha.util.datalog

Database helper utilities.

Database helper utilities.
raw docstring

attrclj/s

(attr db attr)

Get all schema data available about attr itself

Get all schema data available about attr itself
raw docstring

attrsclj/s

(attrs db)

Get all schema data available about every attr present in db

Get all schema data available about every attr present in db
raw docstring

attrs-by-typeclj/s

(attrs-by-type db types)

cardinalityclj/s

(cardinality db attr)

cardinality-many?clj/s

(cardinality-many? db attr)

cardinality-one?clj/s

(cardinality-one? db attr)

docclj/s

(doc db attr)

Get the :db/doc string (if any) of attr

Get the :db/doc string (if any) of attr
raw docstring

empty-queryclj/s

(empty-query)

ensure-attrsclj/s

(ensure-attrs attrs pull)

ensure-db-idclj/s

(ensure-db-id pull)

latest-migrationclj/s

(latest-migration db)

Get the latest migration performed on the given database

Get the latest migration performed on the given database
raw docstring

migrationsclj/s

(migrations db)

All schema changes throughout the history of the given database

All schema changes throughout the history of the given database
raw docstring

normalize-queryclj/s


pull-queryclj/s

(pull-query {:dispatcher/keys [pull]})

Get a basic query with a (pull ...) form in the :find clause

Get a basic query with a (pull ...) form in the :find clause
raw docstring

query-symsclj/s

(query-syms ct)
(query-syms start ct)
(query-syms prefix start ct)

ref?clj/s

(ref? db attr)

relation-reversed?clj/s

(relation-reversed? k)

reverse-relationclj/s

(reverse-relation k)

value-typeclj/s

(value-type db attr)

whereclj/s

(where query constraints)

cljdoc builds & hosts documentation for Clojure/Script libraries