(plugin)(plugin config)Returns a plugin that renders a static file with the fully rendered HTML body of each response.
Returns a plugin that renders a static file with the fully rendered HTML body of each response.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |