systems.bread.alpha.component


component-parentclj/s

(component-parent component)

content-pathclj/s

(content-path component)

defcclj/smacro

(defc sym arglist metadata & exprs)

define-routeclj/s

(define-route {path :path dispatcher :dispatcher/type :as route-data})

Takes a map containing at least the following keys:

  • :path
  • :dispatcher/type Returns a single route spec as a vector. Preserves all other keys in the returned route spec data.
Takes a map containing *at least* the following keys:
- :path
- :dispatcher/type
Returns a single route spec as a vector. Preserves all other keys in the
returned route spec data.
raw docstring

matchclj/s

(match {:systems.bread.alpha.core/keys [data dispatcher] :as res})

pluginclj/s

(plugin)
(plugin {:keys [not-found]})

queryclj/s

(query component)

Get the query for this component.

Get the query for this component.
raw docstring

query-keyclj/s

(query-key component)

Get the key at which this component should show up in ::bread/data.

Get the key at which this component should show up in ::bread/data.
raw docstring

renderclj/s

(render component {:as data :keys [component/extend?] :or {extend? true}})

route-segmentclj/s

(route-segment x)

routesclj/s

(routes cpt)

Takes a component (with metadata) and returns a vector of route definitions, themselves vectors.

Takes a component (with metadata) and returns a vector of route definitions,
themselves vectors.
raw docstring

Sectionclj/smultimethod

cljdoc builds & hosts documentation for Clojure/Script libraries