(add-txs req txs)(add-txs req txs opts)Adds the given txs as effects to be run on the app database. Options include:
Adds the given txs as effects to be run on the app database. Options include: * :description - a custom description to use for :effect/description in the Effect map. Default is "Run database transactions". * :key - the :effect/key to set in the Effect map. Default is nil.
(connection app)(create! {:as db-spec :db/keys [recreate?]})(database app)(delete! config)(exists? db-spec)(migration-key migration)(migration-keys db)Returns the :migration/key of each migration that has been run on db.
Returns the :migration/key of each migration that has been run on db.
(migration-ran? db migration)Returns true if the given migration has been run on db, false otherwise.
Returns true if the given migration has been run on db, false otherwise.
(plugin config)Helper for instantiating a database. Do not call this fn directly from application code; recommended for use from plugins only. Use db/plugin instead.
Helper for instantiating a database. Do not call this fn directly from application code; recommended for use from plugins only. Use db/plugin instead.
(as-of db timepoint)(db-with db txs)(history db)(pull db struct lookup-ref)(q db query)(q db query a)(q db query a b)(q db query a b c)(q db query a b c d)(q db query a b c d e)(q db query a b c d e f)(q db query a b c d e f g)(q db query a b c d e f g h)(q db query a b c d e f g h i)(q db query a b c d e f g h i j)(q db query a b c d e f g h i j k)(q db query a b c d e f g h i j k l)(q db query a b c d e f g h i j k l m)(q db query a b c d e f g h i j k l m n)(q db query a b c d e f g h i j k l m n o)(q db query a b c d e f g h i j k l m n o p)(q db query a b c d e f g h i j k l m n o p q)(q db query a b c d e f g h i j k l m n o p q r)(db conn)(transact conn txs)(txs->effect req
txs
&
{desc :effect/description
k :effect/key
:or {desc "Run database transactions"}})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |