Standard schema for the Bread CMS database.
Standard schema for the Bread CMS database.
Schema for database migrations, so that schema migrations can be reified and self-documenting.
Schema for database migrations, so that schema migrations can be reified and self-documenting.
Minimal schema for posts, the central content type of Bread CMS.
Minimal schema for posts, the central content type of Bread CMS.
Schema for taxons, ways of subdividing posts arbitrarily.
Schema for taxons, ways of subdividing posts arbitrarily.
Schema for generic db entities AKA "Things" that can have children, slugs, sort order, authorship, and a UUID.
Schema for generic db entities AKA "Things" that can have children, slugs, sort order, authorship, and a UUID.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |