(ancestralize query-args slugs & {e :e-sym :or {e (quote ?e)}})Given ::db/query args vector and a list of slugs, returns an args vector asserting that the ancestry of things corresponding to each :thing/slug is an unbroken chain of :thing/children ancestors.
Given ::db/query args vector and a list of slugs, returns an args vector asserting that the ancestry of things corresponding to each :thing/slug is an unbroken chain of :thing/children ancestors.
(by-slug*-expansion {:keys [:systems.bread.alpha.core/dispatcher] :as req})Returns an expansion for querying a single thing matching the ancestry (according to :thing/children) given by the :slugs from the route.
Returns an expansion for querying a single thing matching the ancestry (according to :thing/children) given by the :slugs from the route.
(create-ancestry-rule depth)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |