Database helper utilities.
Database helper utilities.
(attr db attr)Get all schema data available about attr itself
Get all schema data available about attr itself
(attrs db)Get all schema data available about every attr present in db
Get all schema data available about every attr present in db
(attrs-by-type db types)(cardinality db attr)(cardinality-many? db attr)(cardinality-one? db attr)(doc db attr)Get the :db/doc string (if any) of attr
Get the :db/doc string (if any) of attr
(empty-query)(ensure-attrs attrs pull)(ensure-db-id pull)(latest-migration db)Get the latest migration performed on the given database
Get the latest migration performed on the given database
(migrations db)All schema changes throughout the history of the given database
All schema changes throughout the history of the given database
(pull-query {:dispatcher/keys [pull]})Get a basic query with a (pull ...) form in the :find clause
Get a basic query with a (pull ...) form in the :find clause
(query-syms ct)(query-syms start ct)(query-syms prefix start ct)(ref? db attr)(relation-reversed? k)(reverse-relation k)(value-type db attr)(where query constraints)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |